@@ -3,6 +3,8 @@ from django.utils.translation import ugettext_lazy as _
 from transmeta import TransMeta
 from django.template.loader import render_to_string
 
+
+
  
 # -------------------------------------------------------------------------------------------
 
@@ -23,7 +25,7 @@ class Menu(models.Model):
     
     def render(self):        
         sm = self.submenus.all()
-        return render_to_string('menu.html', {'submenus': sm, 'max_depth': 0 })
+        return render_to_string('menu.html', {'name': self.name, 'submenus': sm, 'max_depth': 0 })
         
  
 # -------------------------------------------------------------------------------------------   
@@ -34,11 +36,12 @@ class MenuElement(models.Model):
     label = models.CharField(_('label'), max_length=100)
     order = models.IntegerField(_('Order'))
     url = models.CharField(_('URL'), max_length=100, help_text=_('URL o URI al contenido, ej: /nosotros/ or http://foo.com/'))
+    login_required = models.BooleanField(_('Solo usuarios registrados'),blank=True)
     
     
     class Meta:
-        #verbose_name = _('elemento del menu')
-        #verbose_name_plural = _('elementos del menu')
+        verbose_name = _('elemento del menu')
+        verbose_name_plural = _('elementos del menu')
         translate = ('label', )
         
     def depth(self):
@@ -46,13 +49,27 @@ class MenuElement(models.Model):
         
     def render(self):
         sm = self.submenus.all()
-        return render_to_string('menu.html', {'submenus': sm })
+        return render_to_string('submenu.html', {'submenus': sm })
         
     def __unicode__(self):
         try:
             return "%s" % self.childmenuelement
         except:
-            return "%s" % self.label
+            try:
+                return "%s" % self.parentmenuelement
+            except:
+                return "%s" % self.label
+            
+            
+            
+    def top_menu(self):
+        try:
+            return "%s" % self.childmenuelement.top_menu()
+        except:
+            try:
+                return "%s" % self.parentmenuelement.top_menu()
+            except:
+                return ""
         
         
    
@@ -64,16 +81,17 @@ m.render()
 pme = ParentMenuElement.objects.get(pk=1)
 cm = ChildMenuElement.objects.get(pk=3)
 cm.list()
-
-
 """
-
 # -------------------------------------------------------------------------------------------
 
 
 class ChildMenuElement (MenuElement):
     parent = models.ForeignKey('MenuElement', related_name="submenus")
     
+    class Meta:
+        verbose_name = _('elemento del menu')
+        verbose_name_plural = _('elementos del menu')
+    
     
     def depth(self):
         try:
@@ -86,14 +104,24 @@ class ChildMenuElement (MenuElement):
         return "%s > %s" % (self.parent, self.label)
     
     
+    def top_menu(self):
+        return self.parent.top_menu()
         
     
 class ParentMenuElement (MenuElement):
     menu = models.ForeignKey('Menu', related_name="submenus")
     
+    class Meta:
+        verbose_name = _('elemento del menu')
+        verbose_name_plural = _('elementos del menu')
+    
     
     def depth(self):
         return 1
     
     
+    def __unicode__(self):
+        return "%s > %s" % (self.menu, self.label)  
     
+    def top_menu(self):
+        return self.menu.name
